Installation
============

staircase can be installed from PyPI or Anaconda.

To install the latest version from PyPI::

    python -m pip install staircase

To install the latest version from Anaconda::

    conda install -c venaturum staircase
